@@ -1,13 +1,11 @@
-
-import os, sys, inspect, re, imp, py
-from ctypes_configure import stdoutcapture
+import os, sys, re, imp
+from ctypes_configure import stdoutcapture, TempDir
 import distutils
 
 debug = 0
 
-log = py.log.Producer("cbuild")
+configdir = TempDir(prefix='ctypes_configure-')
 
-configdir = py.path.local.make_numbered_dir(prefix='ctypes_configure')
 
 class ExternalCompilationInfo(object):
 
@@ -115,7 +113,9 @@ class ExternalCompilationInfo(object):
         if not self.separate_module_sources:
             return self
         if cache_dir is None:
-            cache_dir = configdir.join('module_cache').ensure(dir=1)
+            cache_dir = configdir.join('module_cache')
+            if not os.path.isdir(cache_dir):
+                os.mkdir(cache_dir)
         num = 0
         files = []
         for source in self.separate_module_sources:
@@ -201,9 +201,10 @@ def compile_c_module(cfiles, modbasename, eci, tmpdir=None):
     #except ImportError:
     #    print "ERROR IMPORTING"
     #    pass
-    cfiles = [py.path.local(f) for f in cfiles]
     if tmpdir is None:
-        tmpdir = configdir.join("module_cache").ensure(dir=1)
+        tmpdir = configdir.join("module_cache")
+        if not os.path.isdir(tmpdir):
+            os.mkdir(tmpdir)
     num = 0
     cfiles += eci.separate_module_files
     include_dirs = list(eci.include_dirs)
@@ -225,11 +226,11 @@ def compile_c_module(cfiles, modbasename, eci, tmpdir=None):
         num += 1
         modname = '%s_%d' % (modbasename, num)
 
-    lastdir = tmpdir.chdir()
     libraries = eci.libraries
     ensure_correct_math()
     try:
         if debug: print "modname", modname
+        lastdir = os.getcwd()
         c = stdoutcapture.Capture(mixed_out_err = True)
         try:
             try:
@@ -275,7 +276,7 @@ def compile_c_module(cfiles, modbasename, eci, tmpdir=None):
                         attrs = {
                             'name': "testmodule",
                             'ext_modules': [
-                                Extension(modname, [str(cfile) for cfile in cfiles],
+                                Extension(modname, cfiles,
                                     include_dirs=include_dirs,
                                     library_dirs=library_dirs,
                                     extra_compile_args=extra_compile_args,
@@ -286,7 +287,7 @@ def compile_c_module(cfiles, modbasename, eci, tmpdir=None):
                             }
                         dist = Distribution(attrs)
                         if not dist.parse_command_line():
-                            raise ValueError, "distutils cmdline parse error"
+                            raise ValueError("distutils cmdline parse error")
                         dist.run_commands()
                     finally:
                         for key, value in saved_environ:
@@ -305,14 +306,13 @@ def compile_c_module(cfiles, modbasename, eci, tmpdir=None):
             print >>sys.stderr, data
             raise
     finally:
-        lastdir.chdir()
+        os.chdir(lastdir)
     return str(tmpdir.join(modname) + so_ext)
 
 def make_module_from_c(cfile, eci):
-    cfile = py.path.local(cfile)
-    modname = cfile.purebasename
+    modname = os.path.splitext(os.path.basename(cfile))[0]
     compile_c_module([cfile], modname, eci)
-    return import_module_from_directory(cfile.dirpath(), modname)
+    return import_module_from_directory(os.path.dirname(cfile), modname)
 
 def import_module_from_directory(dir, modname):
     file, pathname, description = imp.find_module(modname, [str(dir)])
@@ -327,7 +327,7 @@ def import_module_from_directory(dir, modname):
 def log_spawned_cmd(spawn):
     def spawn_and_log(cmd, *args, **kwds):
         if debug:
-            log.execute(' '.join(cmd))
+            print ' '.join(cmd)
         return spawn(cmd, *args, **kwds)
     return spawn_and_log
 
@@ -335,7 +335,7 @@ def log_spawned_cmd(spawn):
 class ProfOpt(object):
     #XXX assuming gcc style flags for now
     name = "profopt"
-    
+
     def __init__(self, compiler):
         self.compiler = compiler
 
@@ -359,7 +359,7 @@ class ProfOpt(object):
         finally:
             compiler.compile_extra.pop()
             compiler.link_extra.pop()
-            
+
 class CCompiler:
 
     def __init__(self, cfilenames, eci, outputfilename=None,
@@ -383,8 +383,8 @@ class CCompiler:
         if sys.platform == 'win32':
             self.link_extra += ['/DEBUG'] # generate .pdb file
         if sys.platform == 'darwin':
-            # support Fink & Darwinports
-            for s in ('/sw/', '/opt/local/'):
+            # support Fink, Darwinports and Homebrew
+            for s in ('/sw/', '/opt/local/', '/usr/local/'):
                 if s + 'include' not in self.include_dirs and \
                    os.path.exists(s + 'include'):
                     self.include_dirs.append(s + 'include')
@@ -394,18 +394,17 @@ class CCompiler:
             self.compile_extra += ['-O3', '-fomit-frame-pointer']
 
         if outputfilename is None:
-            self.outputfilename = py.path.local(cfilenames[0]).new(ext=ext)
-        else: 
-            self.outputfilename = py.path.local(outputfilename)
+            self.outputfilename = os.path.splitext(cfilenames[0])[0] + ('.' + ext if ext else '')
+        else:
+            self.outputfilename = outputfilename
         self.eci = eci
 
     def build(self, noerr=False):
-        basename = self.outputfilename.new(ext='')
         data = ''
         try:
             saved_environ = os.environ.copy()
+            c = stdoutcapture.Capture(mixed_out_err = True)
             try:
-                c = stdoutcapture.Capture(mixed_out_err = True)
                 self._build()
             finally:
                 # workaround for a distutils bugs where some env vars can
@@ -416,16 +415,16 @@ class CCompiler:
                 foutput, foutput = c.done()
                 data = foutput.read()
                 if data:
-                    fdump = basename.new(ext='errors').open("w")
-                    fdump.write(data)
-                    fdump.close()
+                    errors = os.path.splitext(self.outputfilename)[0] + '.errors'
+                    with open(errors, "w") as fdump:
+                        fdump.write(data)
         except:
             if not noerr:
                 print >>sys.stderr, data
             raise
- 
+
     def _build(self):
-        from distutils.ccompiler import new_compiler 
+        from distutils.ccompiler import new_compiler
         compiler = new_compiler(force=1)
         if self.compiler_exe is not None:
             for c in '''compiler compiler_so compiler_cxx
@@ -433,26 +432,27 @@ class CCompiler:
                 compiler.executables[c][0] = self.compiler_exe
         compiler.spawn = log_spawned_cmd(compiler.spawn)
         objects = []
-        for cfile in self.cfilenames: 
-            cfile = py.path.local(cfile)
-            old = cfile.dirpath().chdir() 
-            try: 
-                res = compiler.compile([cfile.basename], 
+        for cfile in self.cfilenames:
+            old = os.getcwd()
+            os.chdir(os.path.dirname(cfile))
+            try:
+                res = compiler.compile([os.path.basename(cfile)],
                                        include_dirs=self.eci.include_dirs,
                                        extra_preargs=self.compile_extra)
                 assert len(res) == 1
-                cobjfile = py.path.local(res[0]) 
-                assert cobjfile.check()
-                objects.append(str(cobjfile))
-            finally: 
-                old.chdir() 
-        compiler.link_executable(objects, str(self.outputfilename),
-                                 libraries=self.eci.libraries,
-                                 extra_preargs=self.link_extra,
-                                 library_dirs=self.eci.library_dirs)
+                cobjfile = res[0]
+                assert os.path.exists(cobjfile)
+                objects.append(cobjfile)
+
+                compiler.link_executable(objects, str(self.outputfilename),
+                                         libraries=self.eci.libraries,
+                                         extra_preargs=self.link_extra,
+                                         library_dirs=self.eci.library_dirs)
+            finally:
+                os.chdir(old)
 
 def build_executable(*args, **kwds):
     noerr = kwds.pop('noerr', False)
     compiler = CCompiler(*args, **kwds)
     compiler.build(noerr=noerr)
-    return str(compiler.outputfilename)
+    return compiler.outputfilename
