@@ -1,10 +1,11 @@
 #! /usr/bin/env python
 
-import os, py, sys
+import os
+import tempfile
+import subprocess
 import ctypes
 from ctypes_configure.cbuild import build_executable, configdir, try_compile
 from ctypes_configure.cbuild import ExternalCompilationInfo
-import distutils
 
 # ____________________________________________________________
 #
@@ -74,7 +75,7 @@ def memory_alignment():
            };
         """, [])
         result = ctypes.alignment(S)
-        assert result & (result-1) == 0, "not a power of two??"
+        assert result & (result - 1) == 0, "not a power of two??"
         _memory_alignment = result
     return _memory_alignment
 _memory_alignment = None
@@ -89,7 +90,7 @@ class ConfigResult:
         self.result = {}
         self.info = info
         self.entries = entries
-        
+
     def get_entry_result(self, entry):
         try:
             return self.result[entry]
@@ -108,8 +109,8 @@ class _CWriter(object):
     """ A simple class which aggregates config parts
     """
     def __init__(self, CConfig):
-        self.path = uniquefilepath()
-        self.f = self.path.open("w")
+        fd, self.path = tempfile.mkstemp(prefix='ctypesplatcheck_', suffix='.c', dir=str(configdir))
+        self.f = os.fdopen(fd, "w")
         self.config = CConfig
 
     def write_header(self):
@@ -150,8 +151,8 @@ class _CWriter(object):
         eci = self.config._compilation_info_
         return try_compile([self.path], eci)
 
-        
-def configure(CConfig):
+
+def configure(CConfig, noerr=False):
     """Examine the local system by running the C compiler.
     The CConfig class contains CConfigEntry attribues that describe
     what should be inspected; configure() returns a dict mapping
@@ -164,7 +165,7 @@ def configure(CConfig):
     for key in dir(CConfig):
         value = getattr(CConfig, key)
         if isinstance(value, CConfigEntry):
-            entries.append((key, value))            
+            entries.append((key, value))
 
     if entries:   # can be empty if there are only CConfigSingleEntries
         writer = _CWriter(CConfig)
@@ -172,14 +173,13 @@ def configure(CConfig):
         for key, entry in entries:
             writer.write_entry(key, entry)
 
-        f = writer.f
         writer.start_main()
         for key, entry in entries:
             writer.write_entry_main(key)
         writer.close()
 
         eci = CConfig._compilation_info_
-        infolist = list(run_example_code(writer.path, eci))
+        infolist = list(run_example_code(writer.path, eci, noerr=noerr))
         assert len(infolist) == len(entries)
 
         resultinfo = {}
@@ -201,7 +201,6 @@ def configure(CConfig):
             writer = _CWriter(CConfig)
             writer.write_header()
             res[key] = value.question(writer.ask_gcc)
-
     return res
 
 # ____________________________________________________________
@@ -210,7 +209,6 @@ def configure(CConfig):
 class CConfigEntry(object):
     "Abstract base class."
 
-
 class Struct(CConfigEntry):
     """An entry in a CConfig class that stands for an externally
     defined structure.
@@ -235,10 +233,8 @@ class Struct(CConfigEntry):
         yield 'dump("align", offsetof(ctypesplatcheck2_t, s));'
         yield 'dump("size",  sizeof(ctypesplatcheck_t));'
         for fieldname, fieldtype in self.interesting_fields:
-            yield 'dump("fldofs %s", offsetof(ctypesplatcheck_t, %s));'%(
-                fieldname, fieldname)
-            yield 'dump("fldsize %s",   sizeof(s.%s));' % (
-                fieldname, fieldname)
+            yield 'dump("fldofs %s", offsetof(ctypesplatcheck_t, %s));' % (fieldname, fieldname)
+            yield 'dump("fldsize %s",   sizeof(s.%s));' % (fieldname, fieldname)
             if fieldtype in integer_class:
                 yield 's.%s = 0; s.%s = ~s.%s;' % (fieldname,
                                                    fieldname,
@@ -313,7 +309,6 @@ class Struct(CConfigEntry):
         S.__name__ = name
         return S
 
-
 class SimpleType(CConfigEntry):
     """An entry in a CConfig class that stands for an externally
     defined simple numeric type.
@@ -322,7 +317,7 @@ class SimpleType(CConfigEntry):
         self.name = name
         self.ctype_hint = ctype_hint
         self.ifdef = ifdef
-        
+
     def prepare_code(self):
         if self.ifdef is not None:
             yield '#ifdef %s' % (self.ifdef,)
@@ -350,7 +345,6 @@ class SimpleType(CConfigEntry):
             ctype = fixup_ctype(ctype, self.name, (size, sign))
         return ctype
 
-
 class ConstantInteger(CConfigEntry):
     """An entry in a CConfig class that stands for an externally
     defined integer constant.
@@ -422,7 +416,7 @@ class DefinedConstantString(CConfigEntry):
         if info["defined"]:
             string = ''
             d = 0
-            while info.has_key('value_%d' % d):
+            while ('value_%d' % d) in info:
                 string += chr(info['value_%d' % d])
                 d += 1
             return string
@@ -455,7 +449,7 @@ class CConfigSingleEntry(object):
 class Has(CConfigSingleEntry):
     def __init__(self, name):
         self.name = name
-    
+
     def question(self, ask_gcc):
         return ask_gcc(self.name + ';')
 
@@ -484,13 +478,8 @@ def ctype_alignment(c_type):
     if issubclass(c_type, ctypes.Structure):
         return max([ctype_alignment(fld_type)
                      for fld_name, fld_type in c_type._fields_])
-    
-    return ctypes.alignment(c_type)
 
-def uniquefilepath(LAST=[0]):
-    i = LAST[0]
-    LAST[0] += 1
-    return configdir.join('ctypesplatcheck_%d.c' % i)
+    return ctypes.alignment(c_type)
 
 alignment_types = [
     ctypes.c_short,
@@ -517,6 +506,7 @@ class Field(object):
     def __init__(self, name, ctype):
         self.name = name
         self.ctype = ctype
+
     def __repr__(self):
         return '<field %s: %s>' % (self.name, self.ctype)
 
@@ -529,7 +519,7 @@ def layout_addfield(layout, offset, ctype, prefix):
         name = '%s_%d' % (prefix, i)
     field = Field(name, ctype)
     for i in range(offset, offset+size):
-        assert layout[i] is None, "%s overlaps %r" % (fieldname, layout[i])
+        assert layout[i] is None, "%s overlaps %r" % (name, layout[i])
         layout[i] = field
     return field
 
@@ -563,15 +553,18 @@ def fixup_ctype(fieldtype, fieldname, expected_size_and_sign):
 C_HEADER = """
 #include <stdio.h>
 #include <stddef.h>   /* for offsetof() */
+#ifndef _WIN32
+#  include <stdint.h>   /* FreeBSD: for uint64_t */
+#endif
 
 void dump(char* key, int value) {
     printf("%s: %d\\n", key, value);
 }
 """
 
-def run_example_code(filepath, eci):
-    executable = build_executable([filepath], eci)
-    output = py.process.cmdexec(executable)
+def run_example_code(filepath, eci, noerr=False):
+    executable = build_executable([filepath], eci, noerr=noerr)
+    output = subprocess.check_output(executable)
     section = None
     for line in output.splitlines():
         line = line.strip()
@@ -595,7 +588,7 @@ def get_python_include_dir():
 
 if __name__ == '__main__':
     doc = """Example:
-    
+
        ctypes_platform.py  -h sys/types.h  -h netinet/in.h
                            'struct sockaddr_in'
                            sin_port  c_int
